<?php
/*
  Plugin Name: Premium Contents
  Plugin URI: http://www.satollo.net/plugins/premium-contents
  Description: Protect post parts and make them accessible with a key
  Version: 1.1.7
  Author: Stefano Lissa (Satollo)
  Author URI: http://www.satollo.net
  Disclaimer: Use at your own risk. No warranty expressed or implied is provided.
 */

/*
  Copyright 2013 Satollo  (email : stefano@satollo.net)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

define('PREMIUM_CONTENTS_VERSION', '1.1.7');



$pcontents_shortcode = false;

add_shortcode('premium_content', 'pcontents_premium');

function pcontents_premium($attrs, $content) {
    global $post, $cache_stop, $pcontents_shortcode;
    $level = null;
    if (isset($attrs['level']))
        $level = $attrs['level'];
    $box = pcontents_get_box($level);
    if (!empty($box)) {
        $pcontents_shortcode = true;
        return $box;
    }
    return do_shortcode($content);
}

add_filter('the_content', 'pcontents_the_content', 1);

function pcontents_the_content($content) {
    global $post, $cache_stop, $pcontents_shortcode;
    //var_dump($content);
    // If there is premium_content shortcode, do not replace because only some piecies are hidden

    if (!$pcontents_shortcode && strpos($content, '[premium_content') === false) {
        $box = pcontents_get_box();
        if (!empty($box))
            return $box;
    }

    return $content;
}

function pcontents_get_box($level = null) {
    global $post, $cache_stop;
    $options = get_option('premium_contents');


    // Level 3
    $terms = explode(',', $options['terms_3']);
    if ($level == 3 || !empty($options['terms_3']) && (has_tag($terms) || in_category($terms) || in_array($post->post_name, $terms))) {
        $cache_stop = true;
        if (pcontents_is_expired()) {
            return '<div class="premium-contents-message">' . $options['message_3'] . '<div class="premium-contents-button"><a href="' . WP_PLUGIN_URL . '/premium-contents/pay.php">' . $options['button_3'] . '</a></div></div>';
        }
    }


    $terms = explode(',', $options['terms_2']);
    if ($level == '2' || !empty($options['terms_2']) && (has_tag($terms) || in_category($terms) || in_array($post->post_name, $terms))) {
        $cache_stop = true;
        if (!is_user_logged_in()) {

            $login_form = '<div class="premium-contents-login-form">' .
                    '<form action="' . wp_login_url($_SERVER['REQUEST_URI']) . '" method="post">' .
                    __('Username') .
                    '<br /><input type="text" size="20" name="log"/><br />' .
                    __('Password') .
                    '<br /><input type="password" size="20" name="pwd"/><br />' .
                    '<input type="submit" value="' . esc_attr__('Log In') . '" name="wp-submit">' .
                    '<input type="hidden" value="forever" name="rememberme"/>' .
                    '</form><br />' .
                    '<a href="' . site_url('wp-login.php?action=lostpassword', 'login') . '">' .
                    __('Lost your password?') .
                    '</a></div>';

            $register_form = '<div class="premium-contents-signup-form">' .
                    //__('Register For This Site') .
                    '<form action="' . esc_url(site_url('wp-login.php?action=register', 'login_post')) . '" method="post">' .
                    __('Username') .
                    '<br /><input type="text" name="user_login" size="20" /><br>' .
                    __('E-mail') .
                    '<br /><input type="email" name="user_email" required size="25"/><br>' .
                    //do_action('register_form');
                    __('A password will be e-mailed to you.') .
                    '<br />' .
                    '<input type="submit" name="wp-submit" value="' . esc_attr__('Register') . '" /></form>' .
                    '</div>';

            $message = str_replace('_FACEBOOKURL_', plugins_url('premium-contents/facebook.php'), $options['message_2']);
            $message = str_replace('_LOGINFORM_', $login_form, $message);
            $message = str_replace('_REGISTERFORM_', $register_form, $message);
            $message = str_replace('_LOGINURL_', wp_login_url($_SERVER['REQUEST_URI']), $message);
            $message = str_replace('_REGISTERURL_', wp_login_url() . '?action=register', $message);
            
            if (isset($options['show_login_form'])) {

                $message .= $login_form . '<hr>' . $register_form;
            }
            if (!isset($options['show_login_form']) && !empty($options['button_2'])) {
                $message .= '<div class="premium-contents-button"><a href="' . wp_login_url($_SERVER['REQUEST_URI']) . '">' . $options['button_2'] . '</a></div>';
            }
            return '<div class="premium-contents-message">' . $message . '</div>';
        }
    }


    $terms = explode(',', $options['terms_1b']);
    if ($level == '1b' || !empty($options['terms_1b']) && (has_tag($terms) || in_category($terms) || in_array($post->post_name, $terms))) {
        $cache_stop = true;
        if (!isset($_COOKIE['premium_contents'])) {
            $url = $options['like_url'];
            if (empty($url))
                $url = get_permalink();
            return '<div class="premium-contents-message">' . $options['message_1b'] .
                    '<div class="premium-contents-button premium-contents-button-like"><fb:like href="' . $options['like_url'] . '" send="false" layout="button_count" width="120" action="like"></fb:like></div></div>' .
                    '<script>
                    window.fbAsyncInit = function() {
                    FB.Event.subscribe("edge.create", function(response) {
                    location.href = "' . WP_PLUGIN_URL . '/premium-contents/unlock.php";
                    });
                    };
                    </script>';
        }
    }




    $terms = explode(',', $options['terms_1']);
    if ($level == '1' || !empty($options['terms_1']) && (has_tag($terms) || in_category($terms) || in_array($post->post_name, $terms))) {
        $cache_stop = true;
        if (!isset($_COOKIE['premium_contents'])) {
            if (!empty($options['like'])) {
                return '<div class="premium-contents-message">' . $options['message_1'] .
                        '<div class="premium-contents-button premium-contents-button-like"><fb:like href="' . $options['like_url'] . '" send="false" layout="button_count" width="120" action="like"></fb:like></div></div>';
            }
            return '<div class="premium-contents-message">' . $options['message_1'] . '<div class="premium-contents-button"><a href="' . WP_PLUGIN_URL . '/premium-contents/unlock.php">' . $options['button_1'] . '</a></div></div>';
        }
    }
}

function pcontents_is_expired() {
    if (!is_user_logged_in())
        return true;
    $user_id = get_current_user_id();
    $expire_time = get_user_meta($user_id, 'premium_contents_expire', true);
    return $expire_time < time();
}

add_action('show_user_profile', 'pcontents_user_profile');
add_action('edit_user_profile', 'pcontents_user_profile');

function pcontents_user_profile($user) {
    $readonly = !current_user_can('manage_options');
    $expire = get_user_meta($user->ID, 'premium_contents_expire', true);
    ?>

    <h3>Premium Contents</h3>

    <table class="form-table">
        <tr>
            <th>Membership Expiration</th>

            <td>
    <?php if ($readonly) { ?>
        <?php echo esc_attr(date('Y-m-d', (int) $expire)); ?> (the date format is yyyy-mm-dd)
                <?php } else { ?>
                    <input name="premium_contents_expire" value="<?php echo esc_attr(date('Y-m-d', (int) $expire)); ?>"> (yyyy-mm-dd, please pay attention to the date format)
                <?php } ?>
            </td>
        </tr>

    <?php if (!$readonly) { ?>
            <tr>
                <th>Last PayPal IPN</th>

                <td>
                    <textarea><?php echo esc_html(get_user_meta($user->ID, 'premium_contents_ipn', true)); ?></textarea>
                </td>
            </tr>
    <?php } ?>

    </table>
        <?php
    }

// When admin edit itself
    add_action('personal_options_update', 'pcontents_edit_user_profile_update');
    add_action('edit_user_profile_update', 'pcontents_edit_user_profile_update');

    function pcontents_edit_user_profile_update($user_id) {
        if (!current_user_can('manage_options'))
            return;
        $tmp = explode('-', $_POST['premium_contents_expire']);
        $expire = mktime(0, 0, 0, (int) $tmp[1], (int) $tmp[2], (int) $tmp[0]);
        update_usermeta($user_id, 'premium_contents_expire', $expire);
    }

    add_action('wp_footer', 'pcontents_wp_footer');

    function pcontents_wp_footer() {
        $options = get_option('premium_contents');
        if ($options['facebook_sdk']) {
            echo
            '<div id="fb-root"></div>
<script>
(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = "//connect.facebook.net/it_IT/all.js#xfbml=1";
  fjs.parentNode.insertBefore(js, fjs);
}(document, "script", "facebook-jssdk"));
</script>';
        }
    }

    add_action('wp_head', 'pcontents_wp_head');

    function pcontents_wp_head() {
        $options = get_option('premium_contents');
        ?>
    <style>
        .premium-contents-message {
            border-width: <?php echo $options['message_border_width']; ?>px;
            border-radius: <?php echo $options['message_border_radius']; ?>px;
            border-color: <?php echo $options['message_border_color']; ?>;
            border-style: <?php echo $options['message_border_style']; ?>;
            padding: 20px;
            margin: 20px;
            background-color: <?php echo $options['message_bg_color']; ?>;
    <?php if ($options['message_bg_image']) { ?>
                background-image: url("<?php echo WP_PLUGIN_URL; ?>/premium-contents/images/lock-1.png");
    <?php } ?>
            background-position: left top;
            background-repeat: no-repeat;
        }
        .premium-contents-button {
            width: 200px;
            height: 50px;
            margin: 10px auto 0 auto;
            text-align: center;
            background-image: url("<?php echo WP_PLUGIN_URL; ?>/premium-contents/images/button-green.png");
            background-repeat: no-repeat;
            background-position: center center;
            padding-top: 20px;
        }
        .premium-contents-button a {
            font-size: 20px;
            color: #fff;
            text-decoration: none;
        }
        .premium-contents-button-like {
            background-image: none;
        }
    </style>

    <?php
}

if (is_admin()) {
    include WP_PLUGIN_DIR . '/premium-contents/admin.php';
}